==> groupoffice-com-4.0.144.tar.gz: groupoffice-com-4.0.144/modules/calendar/language/de.php <==
<?php

$l["addressbook"]='Adressbuch';
$l["appointments"]='Termine';
$l["recurrence"]='Wiederholung';
$l["options"]='Optionen';
$l["repeatForever"]='unbefristet (immer wiederholen)';
$l["repeatEvery"]='Wiederhole alle';
$l["repeatUntil"]='Bis zum';
$l["busy"]='Als gebucht anzeigen';
$l["allDay"]='Ganztägiger Termin';
$l["navigation"]='Navigation';
$l["oneDay"]='1 Tag';
$l["fiveDays"]='5 Tage';
$l["sevenDays"]='7 Tage';
$l["month"]='Monat';
$l["recurringEvent"]='Wiederkehrender Termin';
$l["deleteRecurringEvent"]='Möchten Sie nur diesen Termin oder die ganze Terminserie löschen?';
$l["singleOccurence"]='Einzelner Termin';
$l["entireSeries"]='Ganze Terminserie';
$l["calendar"]='Kalender';
$l["views"]='Ansichten';
$l["administration"]='Administration';
$l["needsAction"]='Handlungsbedarf';
$l["accepted"]='Angenommen';
$l["declined"]='Abgelehnt';
$l["tentative"]='Vorläufig';
$l["delegated"]='Aufgeteilt';
$l["noRecurrence"]='Keine Wiederholung';
$l["notRespondedYet"]='Noch keine Antwort';
$l["days"]='Tage';
$l["weeks"]='Wochen';
$l["monthsByDate"]='Monate (Datum)';
$l["monthsByDay"]='Monate (Tag)';
$l["years"]='Jahre';
$l["atDays"]='Jeweils am';
$l["noReminder"]='Keine Erinnnerung';
$l["reminder"]='Autom. erinnern';
$l["participants"]='Teilnehmer';
$l["checkAvailability"]='Verfügbarkeit prüfen';
$l["sendInvitation"]='Einladung senden';
$l["emailSendingNotConfigured"]='Das Versenden von E-Mails ist nicht konfiguriert.';
$l["privateEvent"]='Privat';
$l["noInformationAvailable"]='Keine Informationen verfügbar';
$l["noParticipantsToDisplay"]='Keine Teilnehmer vorhanden';
$l["previousDay"]='Vorheriger Tag';
$l["nextDay"]='Nächster Tag';
$l["noAppointmentsToDisplay"]='Keine Termine zum Anzeigen';
$l["selectCalendar"]='Kalender auswählen';
$l["selectCalendarForAppointment"]='Wählen Sie einen Kalender, in den Sie den Termin eintragen möchten';
$l["closeWindow"]='Der Termin wurde akzeptiert und eingetragen. Sie können das Fenster schließen.';
$l["list"]='Liste';
$l["editRecurringEvent"]='Möchten Sie die Wiederholung oder den gesamten Termin bearbeiten?';
$l["selectIcalendarFile"]='Wählen Sie eine iCalendar (*.ics) Datei';
$l["eventDefaults"]='Standardeinstellungen für Termine';
$l["importToCalendar"]='Ohne Einladung direkt in zugehörige Kalender eintragen';
$l["default_calendar"]='Standardkalender';
$l["resource_groups"]='Ressourcengruppen';
$l["resource_group"]='Ressourcengruppe';
$l["resources"]='Ressourcen';
$l["resource"]='Ressource';
$l["calendar_group"]='Kalendergruppe';
$l["admins"]='Administratoren';
$l["no_group_selected"]='Es sind Fehler aufgetreten. Sie müssen eine Gruppe für diese Ressource auswählen.';
$l["visibleCalendars"]='Sichtbare Kalender';
$l["visible"]='Sichtbar';
$l["group"]='Gruppe';
$l["no_status"]='Neu';
$l["no_custom_fields"]='Es stehen keine zusätzlichen Optionen zur Verfügung.';
$l["show_bdays"]='Geburtstage aus Adressbuch anzeigen';
$l["show_tasks"]='Aufgaben aus Aufgabenliste anzeigen';
$l["myCalendar"]='Mein Kalender';
$l["merge"]='Zusammenlegen';
$l["ownColor"]= 'Jedem Kalender eine eigene Farbe zuweisen';
$l["ignoreConflictsTitle"]= 'Konflikt ignorieren?';
$l["ignoreConflictsMsg"]= 'Dieser Termin steht im Konflikt mit einem anderen Termin in Ihrem Kalender. Soll der Termin dennoch gespeichert werden?';
$l["resourceConflictTitle"]= 'Ressourcenkonflikt';
$l["resourceConflictMsg"]= 'Eine oder mehrere Ressourcen in diesem Termin sind schon an anderer Stelle gebucht worden:</br>';
$l["view"]= 'Ansicht';
$l["calendarsPermissions"]='Kalendar Berechtigungen';
$l["resourcesPermissions"]='Resourcen Berechtigungen';

$l["categories"]='Kategorien';
$l["category"]='Kategorie';
$l["globalCategory"]='Globale Kategorie';
$l["selectCategory"]='Kategorie auswählen';
$l["duration"]='Zeitspanne';
$l["move"]='Verschieben';
$l["showInfo"]='Details';
$l["copyEvent"]='Termin kopieren';
$l["moveEvent"]='Termin verschieben';
$l["eventInfo"]='Termindetails';
$l["isOrganizer"]='Organisator';
$l["sendInvitationInitial"]='Möchten Sie eine Termineinladung an die Teilnehmer versenden?';
$l["sendInvitationUpdate"]='Möchten Sie eine Terminaktualisierung an die Teilnehmer versenden?';
$l["sendCancellation"]='Möchten Sie eine Terminabsage an die Teilnehmer versenden?';
$l["forthcomingAppointments"]='Zukünftige Termine';
$l["quarterShort"]= 'Q';
$l["globalsettings_templatelabel"]= 'Vorlage';
$l["globalsettings_allchangelabel"]= 'Alle vorhandenen umbenennen';
$l["globalsettings_renameall"]= 'Sind Sie sicher, dass Sie alle Standard-Benutzer-Kalender umbennen möchten?';
$l["publishICS"]='Alle iCalendar Dateien des letzten Monats und zukünftigen Ereignissen veröffentlichen. Achtung! Der Kalender wird dadurch für jeden lesbar.';
$l["addTimeRegistration"]='Import in Zeiterfassung';
$l["showNotBusy"]='Zeige neue Buchungen nicht als belegt an';
$l["sendEmailParticipants"]= 'Sende E-Mail an Teilnehmer';
$l['name']='Kalender';
$l['description']='Modul zum Verwalten von Terminen';
$l['groupView']='Gruppenansicht';
$l['event']='Ereignis';
$l['startsAt']='Beginnt am';
$l['endsAt']='Endet am';
$l['exceptionNoCalendarID']='ACHTUNG: Keine Kalender-ID!';
$l['allTogether']='Alle zusammen';
$l['invited']='Sie sind zu folgendem Termin eingeladen';
$l['acccept_question']='Möchten Sie diesen Termin wahrnehmen?';
$l['accept']='Annehmen';
$l['decline']='Ablehnen';
$l['bad_event']='Der Termin ist nicht mehr vorhanden';
$l['subject']='Betreff';
$l['status']='Status';
$l['statuses']['NEEDS-ACTION']='Handlungsbedarf';
$l['statuses']['ACCEPTED']='Angenommen';
$l['statuses']['DECLINED']='Abgelehnt';
$l['statuses']['TENTATIVE']='Vorläufig';
$l['statuses']['DELEGATED']='Aufgeteilt';
$l['statuses']['COMPLETED']='Erledigt';
$l['statuses']['IN-PROCESS']='In Bearbeitung';
$l['accept_mail_subject']='Einladung für \'%s\' angenommen';
$l['accept_mail_body']='%s hat ihre Einladung angenommen:';
$l['decline_mail_subject']='Einladung für \'%s\' abgelehnt';
$l['decline_mail_body']='%s hat Ihre Einladung abgelehnt:';
$l['location']='Ort';
$l['and']='und';
$l['repeats']='Wiederhole alle %s';
$l['repeats_at']='Wiederhole alle %s am %s';
$l['repeats_at_not_every']='Wiederhole alle %s %s am %s';
$l['until']='bis'; ;
$l['not_invited']='Sie sind zu diesem Termin nicht eingeladen.';
$l['accept_title']='Akzeptiert';
$l['accept_confirm']='Der Eigentümer wird informiert, dass Sie den Termin angenommen haben';
$l['decline_title']='Abgelehnt';
$l['decline_confirm']='Der Eigentümer wird informiert, dass Sie den Termin abgelehnt haben';
$l['cumulative']='Falsche Wiederholung. Die Wiederholung kann nicht starten, bevor die Vorherige beendet ist.';
$l['already_accepted']='Sie haben diesen Termin schon angenommen.';
$l['private']='Privat';
$l['import_success']='%s Termine wurden importiert';
$l['printTimeFormat']='Von %s bis %s';
$l['printLocationFormat']=' in/bei "%s"';
$l['printPage']='Seite %s von %s';
$l['printList']='Terminliste';
$l['printAllDaySingle']='Ganzer Tag';
$l['printAllDayMultiple']='Ganze Tage vom %s bis zum %s';
$l['calendars']='Kalender';
$l['open_resource']='Freie Ressource';
$l['resource_mail_subject']='Die Ressource \'%s\', gebucht für \'%s\' am \'%s\'';//%s is resource name, %s is event name, %s is start date;
$l['resource_mail_body']='%s hat die Ressource \'%s\' gebucht. Sie sind der Verwalter dieser Ressource. Bitte öffnen Sie die betreffende Buchung, um dieser zuzustimmen oder zu widersprechen.'; //First %s is the name of the person who created the event. Second is the calendar name;
$l['resource_modified_mail_subject']='Resource \'%s\' booking for \'%s\' on \'%s\' modified';//%s is resource name, %s is event name, %s is start date;
$l['resource_modified_mail_body']='%s hat eine Buchung für die Ressource \'%s\' verändert. Sie sind der Verwalter dieser Ressource. Bitte öffnen Sie die betreffende Buchung, um dieser zuzustimmen oder zu widersprechen.'; //First %s is the name of the person who created the event. Second is the calendar name;
$l['your_resource_modified_mail_subject']='Ihre Buchung für \'%s\' am \'%s\' mit Status \'%s\' wurde verändert';//is resource name, %s is event name, %s is start date;
$l['your_resource_modified_mail_body']='%s hat Ihre Buchung für die Ressource \'%s\' verändert.';
$l['your_resource_accepted_mail_subject']='Ihre Buchung für \'%s\' am \'%s\' wurde akzeptiert';//%s is resource name, %s is start date;
$l['your_resource_accepted_mail_body']='%s hat Ihre Buchung für die Ressource \'%s\' akzeptiert.'; //First %s is the name of the person who created the event. Second is the calendar name;
$l['your_resource_declined_mail_subject']='Ihre Buchung für \'%s\' am \'%s\' wurde abgelehnt';//%s is resource name, %s is start date;
$l['your_resource_declined_mail_body']='%s hat Ihre Buchung für die Ressource \'%s\' abgelehnt.'; //First %s is the name of the person who created the event. Second is the calendar name;
$l['birthday_name']='Geburtstag: {NAME}';
$l['birthday_desc']='{NAME} wurde heute {AGE}';
$l['unauthorized_participants_write']='Sie haben keine Befugnisse, Termine für die folgenden Benutzer festzulegen:<br /><br />{NAMES}<br /><br />Wenn Sie Ihnen eine Einladung schicken, werden die Benutzer den Terminen aber eventuell selbst zustimmen.';
$l['noCalSelected'] = 'Für diese Übersicht wurden keine Kalender ausgewählt. Wählen Sie in der Administration zumindest einen Kalender aus.';
$l['month_times'][1]='am Ersten';
$l['month_times'][2]='am Zweiten';
$l['month_times'][3]='am Dritten';
$l['month_times'][4]='am Vierten';
$l['month_times'][5]='am Fünften';
$l['repeats_not_every']= 'Wird alle %s %s wiederholt';
$l['rightClickToCopy']='Rechts klicken um Link zu kopieren';
$l['invitation']='Einladung';
$l['invitation_update']='Aktualisierung';
$l['cancellation']='Absage';
$l['non_selected']= 'nicht in ausgewähltem Kalendar';
$l["confirmed"]= 'Bestätigt';
$l["globalCategories"]='Globale Kategorie';
$l['appointment']= 'Termin';
$l['statuses']['CONFIRMED']= 'Bestätigt';
$l['linkIfCalendarNotSupported']='Nutzen Sie die untenstehenden Links nur, wenn Ihr E-Mailprogramm keine Kalenderfunktionen unterstützt.';
$l['eventAccepted']='Sie haben diesen Termin akzeptiert.';
$l['eventScheduledIn']='Dieser Termin wurde in Ihrem Kalender %s mit dem Status %s eingetragen.';
$l['eventDeclined']="Sie haben den Termin abgelehnt.";
$l['eventUpdatedIn']='Der Termin im Kalender %s wurde mit dem Status %s aktualisiert';
$l['updateReponses'][1]='%s hat den Termin %s akzeptiert';
$l['updateReponses'][2]='%s hat den Termin %s abgewiesen';
$l['updateReponses'][3]='%s hat den Termin %s als vorläufig markiert';
$l['cancelMessage']='Der folgende Termin, zu dem Sie eingeladen waren, wurde abgesagt.';
$l['directUrl']='Direktlink';
$l['cantRemoveOrganizer']="Sie können den Organisator nicht löschen.";
$l['calendarColor']='Kalenderfarbe';

==> groupoffice-com-4.1.7.tar.gz: groupoffice-com-4.1.7/modules/calendar/language/de.php <==
<?php

$l["addressbook"]='Adressbuch';
$l["appointments"]='Termine';
$l["recurrence"]='Wiederholung';
$l["options"]='Optionen';
$l["repeatForever"]='unbefristet (immer wiederholen)';
$l["repeatEvery"]='Wiederhole alle';
$l["repeatUntil"]='Bis zum';
$l["busy"]='Als gebucht anzeigen';
$l["allDay"]='Ganztägiger Termin';
$l["navigation"]='Navigation';
$l["oneDay"]='1 Tag';
$l["fiveDays"]='5 Tage';
$l["sevenDays"]='7 Tage';
$l["month"]='Monat';
$l["recurringEvent"]='Wiederkehrender Termin';
$l["deleteRecurringEvent"]='Möchten Sie nur diesen Termin oder die ganze Terminserie löschen?';
$l["singleOccurence"]='Einzelner Termin';
$l["entireSeries"]='Ganze Terminserie';
$l["calendar"]='Kalender';
$l["views"]='Ansichten';
$l["administration"]='Administration';
$l["needsAction"]='Handlungsbedarf';
$l["accepted"]='Angenommen';
$l["declined"]='Abgelehnt';
$l["tentative"]='Vorläufig';
$l["delegated"]='Aufgeteilt';
$l["noRecurrence"]='Keine Wiederholung';
$l["notRespondedYet"]='Noch keine Antwort';
$l["days"]='Tage';
$l["weeks"]='Wochen';
$l["monthsByDate"]='Monate (Datum)';
$l["monthsByDay"]='Monate (Tag)';
$l["years"]='Jahre';
$l["atDays"]='Jeweils am';
$l["noReminder"]='Keine Erinnnerung';
$l["reminder"]='Autom. erinnern';
$l["participants"]='Teilnehmer';
$l["checkAvailability"]='Verfügbarkeit prüfen';
$l["sendInvitation"]='Einladung senden';
$l["emailSendingNotConfigured"]='Das Versenden von E-Mails ist nicht konfiguriert.';
$l["privateEvent"]='Privat';
$l["noInformationAvailable"]='Keine Informationen verfügbar';
$l["noParticipantsToDisplay"]='Keine Teilnehmer vorhanden';
$l["previousDay"]='Vorheriger Tag';
$l["nextDay"]='Nächster Tag';
$l["noAppointmentsToDisplay"]='Keine Termine zum Anzeigen';
$l["selectCalendar"]='Kalender auswählen';
$l["selectCalendarForAppointment"]='Wählen Sie einen Kalender, in den Sie den Termin eintragen möchten';
$l["closeWindow"]='Der Termin wurde akzeptiert und eingetragen. Sie können das Fenster schließen.';
$l["list"]='Liste';
$l["editRecurringEvent"]='Möchten Sie die Wiederholung oder den gesamten Termin bearbeiten?';
$l["selectIcalendarFile"]='Wählen Sie eine iCalendar (*.ics) Datei';
$l["eventDefaults"]='Standardeinstellungen für Termine';
$l["importToCalendar"]='Ohne Einladung direkt in zugehörige Kalender eintragen';
$l["default_calendar"]='Standardkalender';
$l["resource_groups"]='Ressourcengruppen';
$l["resource_group"]='Ressourcengruppe';
$l["resources"]='Ressourcen';
$l["resource"]='Ressource';
$l["calendar_group"]='Kalendergruppe';
$l["admins"]='Administratoren';
$l["no_group_selected"]='Es sind Fehler aufgetreten. Sie müssen eine Gruppe für diese Ressource auswählen.';
$l["visibleCalendars"]='Sichtbare Kalender';
$l["visible"]='Sichtbar';
$l["group"]='Gruppe';
$l["no_status"]='Neu';
$l["no_custom_fields"]='Es stehen keine zusätzlichen Optionen zur Verfügung.';
$l["show_bdays"]='Geburtstage aus Adressbuch anzeigen';
$l["show_tasks"]='Aufgaben aus Aufgabenliste anzeigen';
$l["myCalendar"]='Mein Kalender';
$l["merge"]='Zusammenlegen';
$l["ownColor"]= 'Jedem Kalender eine eigene Farbe zuweisen';
$l["ignoreConflictsTitle"]= 'Konflikt ignorieren?';
$l["ignoreConflictsMsg"]= 'Dieser Termin steht im Konflikt mit einem anderen Termin in Ihrem Kalender. Soll der Termin dennoch gespeichert werden?';
$l["resourceConflictTitle"]= 'Ressourcenkonflikt';
$l["resourceConflictMsg"]= 'Eine oder mehrere Ressourcen in diesem Termin sind schon an anderer Stelle gebucht worden:</br>';
$l["view"]= 'Ansicht';
$l["calendarsPermissions"]='Kalendar Berechtigungen';
$l["resourcesPermissions"]='Resourcen Berechtigungen';

$l["categories"]='Kategorien';
$l["category"]='Kategorie';
$l["globalCategory"]='Globale Kategorie';
$l["selectCategory"]='Kategorie auswählen';
$l["duration"]='Zeitspanne';
$l["move"]='Verschieben';
$l["showInfo"]='Details';
$l["copyEvent"]='Termin kopieren';
$l["moveEvent"]='Termin verschieben';
$l["eventInfo"]='Termindetails';
$l["isOrganizer"]='Organisator';
$l["sendInvitationInitial"]='Möchten Sie eine Termineinladung an die Teilnehmer versenden?';
$l["sendInvitationUpdate"]='Möchten Sie eine Terminaktualisierung an die Teilnehmer versenden?';
$l["sendCancellation"]='Möchten Sie eine Terminabsage an die Teilnehmer versenden?';
$l["forthcomingAppointments"]='Zukünftige Termine';
$l["quarterShort"]= 'Q';
$l["globalsettings_templatelabel"]= 'Vorlage';
$l["globalsettings_allchangelabel"]= 'Alle vorhandenen umbenennen';
$l["globalsettings_renameall"]= 'Sind Sie sicher, dass Sie alle Standard-Benutzer-Kalender umbennen möchten?';
$l["publishICS"]='Alle iCalendar Dateien des letzten Monats und zukünftigen Ereignissen veröffentlichen. Achtung! Der Kalender wird dadurch für jeden lesbar.';
$l["addTimeRegistration"]='Import in Zeiterfassung';
$l["showNotBusy"]='Zeige neue Buchungen nicht als belegt an';
$l["sendEmailParticipants"]= 'Sende E-Mail an Teilnehmer';
$l['name']='Kalender';
$l['description']='Modul zum Verwalten von Terminen';
$l['groupView']='Gruppenansicht';
$l['event']='Ereignis';
$l['startsAt']='Beginnt am';
$l['endsAt']='Endet am';
$l['exceptionNoCalendarID']='ACHTUNG: Keine Kalender-ID!';
$l['allTogether']='Alle zusammen';
$l['invited']='Sie sind zu folgendem Termin eingeladen';
$l['acccept_question']='Möchten Sie diesen Termin wahrnehmen?';
$l['accept']='Annehmen';
$l['decline']='Ablehnen';
$l['bad_event']='Der Termin ist nicht mehr vorhanden';
$l['subject']='Betreff';
$l['status']='Status';
$l['statuses']['NEEDS-ACTION']='Handlungsbedarf';
$l['statuses']['ACCEPTED']='Angenommen';
$l['statuses']['DECLINED']='Abgelehnt';
$l['statuses']['TENTATIVE']='Vorläufig';
$l['statuses']['DELEGATED']='Aufgeteilt';
$l['statuses']['COMPLETED']='Erledigt';
$l['statuses']['IN-PROCESS']='In Bearbeitung';
$l['accept_mail_subject']='Einladung für \'%s\' angenommen';
$l['accept_mail_body']='%s hat ihre Einladung angenommen:';
$l['decline_mail_subject']='Einladung für \'%s\' abgelehnt';
$l['decline_mail_body']='%s hat Ihre Einladung abgelehnt:';
$l['location']='Ort';
$l['not_invited']='Sie sind zu diesem Termin nicht eingeladen.';
$l['accept_title']='Akzeptiert';
$l['accept_confirm']='Der Eigentümer wird informiert, dass Sie den Termin angenommen haben';
$l['decline_title']='Abgelehnt';
$l['decline_confirm']='Der Eigentümer wird informiert, dass Sie den Termin abgelehnt haben';
$l['cumulative']='Falsche Wiederholung. Die Wiederholung kann nicht starten, bevor die Vorherige beendet ist.';
$l['already_accepted']='Sie haben diesen Termin schon angenommen.';
$l['private']='Privat';
$l['import_success']='%s Termine wurden importiert';
$l['printTimeFormat']='Von %s bis %s';
$l['printLocationFormat']=' in/bei "%s"';
$l['printPage']='Seite %s von %s';
$l['printList']='Terminliste';
$l['printAllDaySingle']='Ganzer Tag';
$l['printAllDayMultiple']='Ganze Tage vom %s bis zum %s';
$l['calendars']='Kalender';
$l['open_resource']='Freie Ressource';
$l['resource_mail_subject']='Die Ressource \'%s\', gebucht für \'%s\' am \'%s\'';//%s is resource name, %s is event name, %s is start date;
$l['resource_mail_body']='%s hat die Ressource \'%s\' gebucht. Sie sind der Verwalter dieser Ressource. Bitte öffnen Sie die betreffende Buchung, um dieser zuzustimmen oder zu widersprechen.'; //First %s is the name of the person who created the event. Second is the calendar name;
$l['resource_modified_mail_subject']='Resource \'%s\' booking for \'%s\' on \'%s\' modified';//%s is resource name, %s is event name, %s is start date;
$l['resource_modified_mail_body']='%s hat eine Buchung für die Ressource \'%s\' verändert. Sie sind der Verwalter dieser Ressource. Bitte öffnen Sie die betreffende Buchung, um dieser zuzustimmen oder zu widersprechen.'; //First %s is the name of the person who created the event. Second is the calendar name;
$l['your_resource_modified_mail_subject']='Ihre Buchung für \'%s\' am \'%s\' mit Status \'%s\' wurde verändert';//is resource name, %s is event name, %s is start date;
$l['your_resource_modified_mail_body']='%s hat Ihre Buchung für die Ressource \'%s\' verändert.';
$l['your_resource_accepted_mail_subject']='Ihre Buchung für \'%s\' am \'%s\' wurde akzeptiert';//%s is resource name, %s is start date;
$l['your_resource_accepted_mail_body']='%s hat Ihre Buchung für die Ressource \'%s\' akzeptiert.'; //First %s is the name of the person who created the event. Second is the calendar name;
$l['your_resource_declined_mail_subject']='Ihre Buchung für \'%s\' am \'%s\' wurde abgelehnt';//%s is resource name, %s is start date;
$l['your_resource_declined_mail_body']='%s hat Ihre Buchung für die Ressource \'%s\' abgelehnt.'; //First %s is the name of the person who created the event. Second is the calendar name;
$l['birthday_name']='Geburtstag: {NAME}';
$l['birthday_desc']='{NAME} wurde heute {AGE}';
$l['unauthorized_participants_write']='Sie haben keine Befugnisse, Termine für die folgenden Benutzer festzulegen:<br /><br />{NAMES}<br /><br />Wenn Sie Ihnen eine Einladung schicken, werden die Benutzer den Terminen aber eventuell selbst zustimmen.';
$l['noCalSelected'] = 'Für diese Übersicht wurden keine Kalender ausgewählt. Wählen Sie in der Administration zumindest einen Kalender aus.';

$l['repeats_not_every']= 'Wird alle %s %s wiederholt';
$l['rightClickToCopy']='Rechts klicken um Link zu kopieren';
$l['invitation']='Einladung';
$l['invitation_update']='Aktualisierung';
$l['cancellation']='Absage';
$l['non_selected']= 'nicht in ausgewähltem Kalendar';
$l["confirmed"]= 'Bestätigt';
$l["globalCategories"]='Globale Kategorie';
$l['appointment']= 'Termin';
$l['statuses']['CONFIRMED']= 'Bestätigt';
$l['linkIfCalendarNotSupported']='Nutzen Sie die untenstehenden Links nur, wenn Ihr E-Mailprogramm keine Kalenderfunktionen unterstützt.';
$l['eventAccepted']='Sie haben diesen Termin akzeptiert.';
$l['eventScheduledIn']='Dieser Termin wurde in Ihrem Kalender %s mit dem Status %s eingetragen.';
$l['eventDeclined']="Sie haben den Termin abgelehnt.";
$l['eventUpdatedIn']='Der Termin im Kalender %s wurde mit dem Status %s aktualisiert';
$l['updateReponses']["ACCEPTED"]='%s hat den Termin %s akzeptiert';
$l['updateReponses']["DECLINED"]='%s hat den Termin %s abgewiesen';
$l['updateReponses']["TENTATIVE"]='%s hat den Termin %s als vorläufig markiert';
$l['cancelMessage']='Der folgende Termin, zu dem Sie eingeladen waren, wurde abgesagt.';
$l['directUrl']='Direktlink';
$l['cantRemoveOrganizer']="Sie können den Organisator nicht löschen.";
$l['calendarColor']='Kalenderfarbe';
